##  Summary
This tutorial provided detailed guidance on how to create a custom pie chart report showing the average completion score of fact sheets of a specific type. You learned how to:
  * Use the [lx.openFormModal![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Fclasses%2Flxr.LxCustomReportLib.html%23openFormModal "https://leanix.github.io/leanix-reporting/classes/lxr.LxCustomReportLib.html#openFormModal") method to create and manage custom modals within the LeanIX Reporting Framework
  * Use the [lx.executeGraphQL![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Fclasses%2Flxr.LxCustomReportLib.html%23executeGraphQL "https://leanix.github.io/leanix-reporting/classes/lxr.LxCustomReportLib.html#executeGraphQL") method to retrieve your workspace data through the GraphQL API
  * Calculate the average completion score of fact sheets of a specific type, which is a critical aspect of maintaining high data quality in your workspace
  * Visualize workspace data using a third-party library
